@@ -1,7 +1,7 @@
 """Custom decorators for API class."""
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 
 from loguru import logger
 
@@ -9,7 +9,7 @@ if TYPE_CHECKING:
     from shikithon.api import API
 
 
-def protected_method(scope=None):
+def protected_method(scope: Optional[str] = None):
     """
     Decorator for protected API methods.
 
@@ -24,9 +24,9 @@ def protected_method(scope=None):
     protected method.
     """
 
-    def decorator(function):
+    def protected_method_decorator(function):
 
-        def wrapper(api: API, *args, **kwargs):
+        def protected_method_wrapper(api: API, *args, **kwargs):
             """
             Decorator's wrapper function.
 
@@ -55,6 +55,26 @@ def protected_method(scope=None):
                          'method have been passed')
             return function(api, *args, **kwargs)
 
-        return wrapper
+        return protected_method_wrapper
 
-    return decorator
+    return protected_method_decorator
+
+
+def method_endpoint(method_endpoint_name: str):
+    """
+    Decorator for logging method endpoint.
+    """
+
+    def endpoint_logger_decorator(function):
+
+        def endpoint_logger_wrapper(*args, **kwargs):
+            """
+            Decorator's wrapper function.
+            Logs endpoint of method
+            """
+            logger.debug(f'Executing "{method_endpoint_name}" method')
+            return function(*args, **kwargs)
+
+        return endpoint_logger_wrapper
+
+    return endpoint_logger_decorator
