@@ -4,10 +4,10 @@ Enums for /api/person.
 Also PersonKind enum is use in /api/favorites,
 when linked_type is Person
 """
-from enum import Enum
+from shikithon.enums.enhanced_enum import EnhancedEnum
 
 
-class PersonKind(Enum):
+class PersonKind(EnhancedEnum):
     """Contains constants related for favorite person kind."""
     NONE = ''
     COMMON = 'common'
