@@ -1,8 +1,8 @@
 """Enums for /api/styles."""
-from enum import Enum
+from shikithon.enums.enhanced_enum import EnhancedEnum
 
 
-class OwnerType(Enum):
+class OwnerType(EnhancedEnum):
     """Contains constants related for style owner type."""
     USER = 'User'
     CLUB = 'Club'
