@@ -1,6 +1,6 @@
 """Model for /api/animes"""
 from datetime import datetime
-from typing import List, Optional, Union
+from typing import List, Optional
 
 from pydantic import BaseModel
 
@@ -29,9 +29,9 @@ class Anime(BaseModel):
     aired_on: Optional[str]
     released_on: Optional[str]
     rating: Optional[str]
-    english: Optional[List[Union[str, None]]]
-    japanese: Optional[List[Union[str, None]]]
-    synonyms: Optional[List[Union[str, None]]]
+    english: Optional[List[Optional[str]]]
+    japanese: Optional[List[Optional[str]]]
+    synonyms: Optional[List[Optional[str]]]
     license_name_ru: Optional[str]
     duration: Optional[int]
     description: Optional[str]
